ArsenalColors class abstract final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

accent → const Color
accentDim → const Color
background → const Color
border → const Color
error → const Color
gradientCenter → const Color
muted → const Color
onBackground → const Color
onSurface → const Color
scrim → const Color
surface → const Color
surfaceVariant → const Color