Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- avatarLg → const double
- avatarMd → const double
- avatarSm → const double
- chipHeight → const double
- iconLg → const double
- iconMd → const double
- iconSm → const double
- lg → const double
- md → const double
- radiusNone → const double
- sm → const double
- xl → const double
- xs → const double
- xxl → const double
- xxxl → const double