copyWith method
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
Implementation
@override
ArsenalTheme copyWith() => const ArsenalTheme();
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
@override
ArsenalTheme copyWith() => const ArsenalTheme();