ArsenalTheme class
- Inheritance
-
- Object
- ThemeExtension<
ArsenalTheme> - ArsenalTheme
- Annotations
Constructors
- ArsenalTheme()
-
const
Properties
Methods
-
copyWith(
) → ArsenalTheme -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< ArsenalTheme> ? other, double t) → ArsenalTheme -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → ArsenalTheme