Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- body → const TextStyle
- 16px Rajdhani w500 — Body copy
- bodySmall → const TextStyle
- 14px Rajdhani w500 — Secondary body
- 14px Rajdhani w700 UPPERCASE — Button text
- displayLarge → const TextStyle
- 40px BigShouldersDisplay w800 UPPERCASE — Major section headers
- displayMedium → const TextStyle
- 32px BigShouldersDisplay w800 — Section headers
- hero → const TextStyle
- 48px BigShouldersDisplay w800 UPPERCASE — Screen hero titles
- label → const TextStyle
- 12px Rajdhani w600 — Standard UI labels
- labelEmphasis → const TextStyle
- 13px Rajdhani w700 — UI emphasis labels
- mono → const TextStyle
- 12px JetBrainsMono w400 — Timestamps, secondary technical text
- monoHighlight → const TextStyle
- 13px JetBrainsMono w700 UPPERCASE — Step counters, status, codes
- subheadingLarge → const TextStyle
- 24px Rajdhani w600 — Subheadings
- subheadingMedium → const TextStyle
- 18px Rajdhani w600 — Card titles